/*-----------------------------------------------------------------------
|                            FILE DESCRIPTION                           |
-----------------------------------------------------------------------*/
/*----------------------------------------------------------------------
  - File name     : example_mpwm.c
  - Author        : slipperstree
  - Update date   : 2022.07.03
-----------------------------------------------------------------------*/
/*------------------------------------------------------------------------
|                            COPYRIGHT NOTICE                            |
------------------------------------------------------------------------*/
/*
 * Copyright (C) 2022, slipperstree (https://gitee.com/slipperstree)

 * This file is part of 8051 ELL low-layer libraries.

 * 8051 ELL low-layer libraries is free software: you can redistribute 
 * it and/or modify it under the terms of the Apache-2.0 License.

 * 8051 ELL low-layer libraries is distributed in the hope that it will 
 * be useful,but WITHOUT ANY WARRANTY; without even the implied warranty 
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * Apache-2.0 License for more details.

 * You should have received a copy of the Apache-2.0 License.8051 ELL 
 * low-layer libraries. If not, see <http://www.apache.org/licenses/>.
**/
/*-----------------------------------------------------------------------
|                               INCLUDES                                |
-----------------------------------------------------------------------*/
#include "example_mpwm.h"
#include "ELL_LIB.h"

/*-----------------------------------------------------------------------
|                                 DATA                                  |
-----------------------------------------------------------------------*/
/* None. */
/*-----------------------------------------------------------------------
|                               FUNCTION                                |
-----------------------------------------------------------------------*/

/**
 * @brief      MPWMʾʼ
 * @details    Example code for MPWM peripherals initialized.
 * @param      None.
 * @return     None.
 * @note       ỵֻ̈ܵһʼк֮䲢ݡ
 *             Each routine can only call an initialization function and a run function, 
 *             and the routines are not compatible with each other.
**/
void Example_MPWM_Init(void)
{
	GPIO_MODE_OUT_PP(GPIO_P0,Pin_4);
	GPIO_MODE_OUT_PP(GPIO_P0,Pin_5);
	GPIO_MODE_OUT_PP(GPIO_P4,Pin_7);

	/* Init PWM port 0 */
	UART1_Isr_Send_String("Init PWM port 0 \r\n");
	MPWMn_Port_Init(MPWM_Port_0, MPWM_SCLK_DIV_16, 0x1000);	

	/* Init PWM channel P04 */
	UART1_Isr_Send_String("Init PWM channel P04 \r\n");
	MPWMn_Channel_Init(MPWM_Port_0, MPWM_Channel_4, MPWM_Start_Low_Level, 0x0000, 0x0200, ENABLE);

	/* Init PWM channel P05 but output is disabled */
	UART1_Isr_Send_String("Init PWM channel P05 but output is disabled \r\n");
	MPWMn_Channel_Init(MPWM_Port_0, MPWM_Channel_5, MPWM_Start_Low_Level, 0x0000, 0x0500, DISABLE);

	/* Init PWM channel P47 while PWM port 4 hasn't initalized yet */
	UART1_Isr_Send_String("Init PWM channel P47 while PWM port 4 hasn't initalized yet \r\n");
	MPWMn_Channel_Init(MPWM_Port_4, MPWM_Channel_7, MPWM_Start_Low_Level, 0x0100, 0x0500, ENABLE);

	/* Init PWM port 4 */
	UART1_Isr_Send_String("Init PWM port 4 \r\n");
	MPWMn_Port_Init(MPWM_Port_4, MPWM_SCLK_DIV_16, 0x1000);
}


/**
 * @brief      MPWMʾ롣
 * @details    Run the MPWM peripheral sample code.
 * @param      None.
 * @return     None.
 * @note       ỵֻ̈ܵһʼк֮䲢ݡ
 *             Each routine can only call an initialization function and a run function, 
 *             and the routines are not compatible with each other.
**/
void Example_MPWM_Run(void)
{
	/* Run PWM port 0 */
	/*  PWM port 0 */
	MPWMn_Run(MPWM_Port_0);

	/* Run PWM port 4 */
	/*  PWM port 4 */
	MPWMn_Run(MPWM_Port_4);

	DELAY_Set_Ms(3000);  // Wait a while to see what happening ȴһ۲
	// Now, P04 is working.  P04ѾˣInitѾʼP04OutPutΪENABLE
	//      P05 is not work cause output is disabled P05ûпʼΪInitP05OutPutΪDisable
	//      P47 is not work cause PORT MUST BE INITALIZED FIRST BEFORE CHANNEL P07ҲûйΪPORT֮ͨǰʼ˳ܷ
	// 

	/* Enable P05 Output by Set Register [PWMnCR]'s bit [ENO[7:7]] to 1 directly ͨüĴķʽP05outputΪenable */
	/* (Or you can just call MPWMn_Channel_Init() again by pass ENABLE to last param [run]) Ҳµһγʼ MPWMn_Channel_Init ΪENABLE*/
	EAXFR_ENABLE();
	setBitPWMniEnableOut(MPWM_Port_0, MPWM_Channel_5);
	EAXFR_DISABLE();

	DELAY_Set_Ms(3000);  // Wait a while to see what happening ȴһ۲
	// 
	// P05 is now working. fine. P05ʼ
	// 

	/* Like P05, let's try enable P47 Output by Set Register [PWMnCR]'s bit [ENO[7:7]] to 1 directly P05һͨüĴķʽP47outputΪenable */
	EAXFR_ENABLE();
	setBitPWMniEnableOut(MPWM_Port_4, MPWM_Channel_7);
	EAXFR_DISABLE();

	DELAY_Set_Ms(3000);  // Wait a while to see what happening ȴһ۲
	//
	// Oh no! P47 is still sleeping cause initalized values(StartLevel/T1/T2) hasn't been affected at all. ʱP47Ȼûпʼ
	// 

	/* So you need init P47 by call MPWMn_Channel_Init() again ҪMPWMn_Channel_Init³ʼһP47 */
	MPWMn_Channel_Init(MPWM_Port_4, MPWM_Channel_7, MPWM_Start_Low_Level, 0x0100, 0x0500, ENABLE);

	DELAY_Set_Ms(3000);  // Wait a while to see what happening ȴһ۲
	//
	// P47 is running now! P47
	// PORT MUST BE INITALIZED FIRST BEFORE CHANNEL. PORT֮ͨǰʼҪһ
	// Don't forget it.
	// 

	/* Stop PWM port 0 ֹͣPORT0PWM */
	MPWMn_Stop(MPWM_Port_0);

	DELAY_Set_Ms(3000);  // Wait a while to see what happening ȴһ۲
	//
	// Now, P04/P05 stoped. P04P05ֹͣ
	// 
	
	/* Stop PWM port 4 ֹͣPORT4PWM  */
	UART1_Isr_Send_String("Stop PWM port 4 \r\n");
	MPWMn_Stop(MPWM_Port_4);

	DELAY_Set_Ms(3000);  // Wait a while to see what happening ȴһ۲
	//
	// Now, P47 stoped as well. P47Ҳֹͣ
	//

	DELAY_Set_Ms(5000);  // Wait a while to see what happening
}

/*-----------------------------------------------------------------------
|                   END OF FLIE.  (C) COPYRIGHT slipperstree            |
-----------------------------------------------------------------------*/



